==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1TokenReviewSpecBuilder.java <==
package io.kubernetes.client.models;

import io.kubernetes.client.fluent.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class V1TokenReviewSpecBuilder extends V1TokenReviewSpecFluentImpl<V1TokenReviewSpecBuilder> implements VisitableBuilder<V1TokenReviewSpec,V1TokenReviewSpecBuilder>{

    V1TokenReviewSpecFluent<?> fluent;
    Boolean validationEnabled;

    public V1TokenReviewSpecBuilder(){
            this(true);
    }
    public V1TokenReviewSpecBuilder(Boolean validationEnabled){
            this(new V1TokenReviewSpec(), validationEnabled);
    }
    public V1TokenReviewSpecBuilder(V1TokenReviewSpecFluent<?> fluent){
            this(fluent, true);
    }
    public V1TokenReviewSpecBuilder(V1TokenReviewSpecFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new V1TokenReviewSpec(), validationEnabled);
    }
    public V1TokenReviewSpecBuilder(V1TokenReviewSpecFluent<?> fluent,V1TokenReviewSpec instance){
            this(fluent, instance, true);
    }
    public V1TokenReviewSpecBuilder(V1TokenReviewSpecFluent<?> fluent,V1TokenReviewSpec instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withToken(instance.getToken());

            this.validationEnabled = validationEnabled; 
    }
    public V1TokenReviewSpecBuilder(V1TokenReviewSpec instance){
            this(instance,true);
    }
    public V1TokenReviewSpecBuilder(V1TokenReviewSpec instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withToken(instance.getToken());

            this.validationEnabled = validationEnabled; 
    }

    public V1TokenReviewSpec build(){
            V1TokenReviewSpec buildable = new V1TokenReviewSpec();
            buildable.setToken(fluent.getToken());
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1TokenReviewSpecBuilder that = (V1TokenReviewSpecBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1TokenReviewSpecBuilder.java <==
package io.kubernetes.client.models;

import io.kubernetes.client.fluent.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class V1TokenReviewSpecBuilder extends V1TokenReviewSpecFluentImpl<V1TokenReviewSpecBuilder> implements VisitableBuilder<V1TokenReviewSpec,V1TokenReviewSpecBuilder>{

    V1TokenReviewSpecFluent<?> fluent;
    Boolean validationEnabled;

    public V1TokenReviewSpecBuilder(){
            this(true);
    }
    public V1TokenReviewSpecBuilder(Boolean validationEnabled){
            this(new V1TokenReviewSpec(), validationEnabled);
    }
    public V1TokenReviewSpecBuilder(V1TokenReviewSpecFluent<?> fluent){
            this(fluent, true);
    }
    public V1TokenReviewSpecBuilder(V1TokenReviewSpecFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new V1TokenReviewSpec(), validationEnabled);
    }
    public V1TokenReviewSpecBuilder(V1TokenReviewSpecFluent<?> fluent,V1TokenReviewSpec instance){
            this(fluent, instance, true);
    }
    public V1TokenReviewSpecBuilder(V1TokenReviewSpecFluent<?> fluent,V1TokenReviewSpec instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withAudiences(instance.getAudiences());

            fluent.withToken(instance.getToken());

            this.validationEnabled = validationEnabled; 
    }
    public V1TokenReviewSpecBuilder(V1TokenReviewSpec instance){
            this(instance,true);
    }
    public V1TokenReviewSpecBuilder(V1TokenReviewSpec instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withAudiences(instance.getAudiences());

            this.withToken(instance.getToken());

            this.validationEnabled = validationEnabled; 
    }

    public V1TokenReviewSpec build(){
            V1TokenReviewSpec buildable = new V1TokenReviewSpec();
            buildable.setAudiences(fluent.getAudiences());
            buildable.setToken(fluent.getToken());
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1TokenReviewSpecBuilder that = (V1TokenReviewSpecBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
